@@ -52,7 +52,7 @@ impl<'info> Validate<'info> for CancelProposal<'info> {
     fn validate(&self) -> ProgramResult {
         invariant!(
             self.proposal.get_state(&self.governor)? == ProposalState::Draft,
-            "proposal must be draft to be cancelled"
+            "proposal must be draft to be canceled"
         );
         assert_keys_eq!(
             self.proposer,
